@@ -26,8 +26,10 @@ import random
 import sys
 if sys.version < '3':
   from urllib import quote
+  from urllib import urlencode
 else:
   from urllib.parse import quote
+  from urllib.parse import urlencode
 import urllib3
 import time
 
@@ -286,7 +288,7 @@ class Index:
         if args == None:
             return AlgoliaUtils_request(self.headers, self.hosts, "GET", "/1/indexes/%s?query=%s" % (self.urlIndexName, quote(query.encode('utf8'))))
         else:
-            return AlgoliaUtils_request(self.headers, self.hosts, "GET", "/1/indexes/%s?query=%s&%s" % (self.urlIndexName, quote(query.encode('utf8')), urllib.urlencode(args)))
+            return AlgoliaUtils_request(self.headers, self.hosts, "GET", "/1/indexes/%s?query=%s&%s" % (self.urlIndexName, quote(query.encode('utf8')), urlencode(args)))
 
     """
     Wait the publication of a task on the server. 
